@@ -53,15 +53,14 @@ GVContactsTable::deinitModel ()
 }//GVContactsTable::deinitModel
 
 void
-GVContactsTable::initModel (QDeclarativeView *pMainWindow)
+GVContactsTable::initModel ()
 {
     deinitModel ();
 
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     modelContacts = dbMain.newContactsModel ();
 
-    QDeclarativeContext *ctx = pMainWindow->rootContext();
-    ctx->setContextProperty ("g_contactsModel", modelContacts);
+    emit setContactsModel (modelContacts);
 
     while (modelContacts->canFetchMore ()) {
         modelContacts->fetchMore ();
@@ -302,7 +301,7 @@ GVContactsTable::onGotContacts (QNetworkReply *reply)
         }
 
 #if 0
-        QFile temp("dump.txt");
+        QFile temp("contacts.txt");
         temp.open (QIODevice::ReadWrite);
         temp.write (byData);
         temp.close ();
@@ -342,13 +341,10 @@ GVContactsTable::gotOneContact (const ContactInfo &contactInfo)
     dbMain.setQuickAndDirty();
 
     QMutexLocker locker(&mutex);
-    if (contactInfo.bDeleted)
-    {
+    if (contactInfo.bDeleted) {
         qDebug() << "Delete contact " << contactInfo.strTitle;
         modelContacts->deleteContact (contactInfo);
-    }
-    else    // add or modify
-    {
+    } else {   // add or modify
         qDebug() << "Insert contact " << contactInfo.strTitle;
         modelContacts->insertContact (contactInfo);
     }
